Struct tracing_forest::builder::SubscriberBuilder
source · [−]pub struct SubscriberBuilder<S, E> { /* private fields */ }Expand description
A type for building Subscribers by composing many Layers, while also
holding extension data necessary for some TreeLayer types.
Implementations
impl<S, E> SubscriberBuilder<S, AsyncExtensions<E>> where
S: Subscriber + Send + Sync,
E: 'static + Future<Output = ()> + Send,
impl<S, E> SubscriberBuilder<S, AsyncExtensions<E>> where
S: Subscriber + Send + Sync,
E: 'static + Future<Output = ()> + Send,
Runs the provided closure in the context of a subscriber layered with a
TreeLayer.