Derive Macro tracing_forest::Tag

source · []
#[derive(Tag)]
{
    // Attributes available to this derive:
    #[tag]
}
Derive macro generating an implementation of the Tag trait.

See tag module documentation for details on how to define and use tags.