Struct tracing_forest::layer::TreeSpan
source · [−]pub struct TreeSpan {
pub name: &'static str,
pub duration_total: Duration,
pub duration_nested: Duration,
pub children: Vec<Tree>,
}Expand description
Information unique to logged spans.
Fields
name: &'static strThe name of the span.
duration_total: DurationThe duration that the span was entered for.
duration_nested: DurationThe duration that child spans of this span were entered for.
children: Vec<Tree>Spans and events that occurred inside of this span.