macro_rules! uuid_debug_span {
    ($uuid:expr, $name:expr, $( $fields:tt )*) => { ... };
    ($uuid:expr, $name:expr) => { ... };
}
Creates a new Span at the debug level with a specified Uuid.

This macro provides a useful subset of the functionality of tracings debug_span! macro, except is accepts a Uuid as the first argument to set the span’s ID.

Examples

let id = Uuid::new_v4();
uuid_debug_span!(id, "my_span");
// is equivalent to:
uuid_span!(id, Level::DEBUG, "my_span");

Creating a new trace span with a specified Uuid:

let id = Uuid::new_v4();
let span = uuid_debug_span!(id, "my_span");
let _enter = span.enter();
// do work inside the span...