Trait for processing logs of a span after it is closed.

See Processor for more details.

Re-exports

pub use blocking::BlockingProcessor;
pub use sync::AsyncProcessor;

Modules

A Processor that formats and writes logs on the current thread.

A Processor that sends logs to another task to be processed.

Traits

A type that can process trace trees.